Usage
=====

Installation
------------

To use mylib, first install it by downloading the source code of **mylib** from `mylib GitHub <https://github.com/ZLoverty/mylib>`_ to a local folder, then set this folder to python path, by using

.. code-block:: console

  conda-develope /your/local/mylib
